@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: config.c,v 1.115 2012/03/19 11:38:43 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -703,6 +703,9 @@ config_t::config_t() {
   ff_h264_skip_loop_filter     = FF_H264_SKIP_LOOPFILTER_auto;
 
   strn0cpy(media_root_dir,    "/",            sizeof(media_root_dir));
+#if defined(APIVERSNUM) && (APIVERSNUM >= 20102)
+  const char *VideoDirectory = cVideoDirectory::Name() ? cVideoDirectory::Name() : VIDEODIR;
+#endif
   strn0cpy(browse_files_dir,  VideoDirectory, sizeof(browse_files_dir));
   strn0cpy(browse_music_dir,  VideoDirectory, sizeof(browse_music_dir));
   strn0cpy(browse_images_dir, VideoDirectory, sizeof(browse_images_dir));
@@ -712,10 +715,12 @@ config_t::config_t() {
   dvd_arrow_keys_control_playback = 1;
   media_menu_items = ~0;
   media_enable_delete = 0;
+  media_enable_resume = 1;
 
   main_menu_mode = ShowMenu;
   last_hotkey = -1;//kNone;
   force_primary_device = 0;
+  use_suspendoutput = 0;
 };
 
 #if 0
@@ -728,7 +733,7 @@ uint8_t *config_t::readonly_options = &g_readonly_options[0];
 cString config_t::m_ProcessedArgs;
 bool config_t::ProcessArg(const char *Name, const char *Value)
 {
-  if(SetupParse(Name, Value)) {
+  if (Name && Value && SetupParse(Name, Value)) {
     m_ProcessedArgs = cString::sprintf("%s%s ", *m_ProcessedArgs ? *m_ProcessedArgs : " ", Name);
     return true;
   }
@@ -737,7 +742,7 @@ bool config_t::ProcessArg(const char *Name, const char *Value)
 
 bool config_t::ProcessArgs(int argc, char *argv[])
 {
-  static const char short_options[] = "fDw:h:l:mr:A:V:d:P:C:pc";
+  static const char short_options[] = "fDw:h:l:mr:A:V:d:P:C:pct";
 
   static const struct option long_options[] = {
       { "fullscreen",   no_argument,       NULL, 'f' },
@@ -759,7 +764,9 @@ bool config_t::ProcessArgs(int argc, char *argv[])
       { "post",         required_argument, NULL, 'P' },
       { "config",       required_argument, NULL, 'C' },
       { "primary",      no_argument,       NULL, 'p' },
+      { "auto-suspend", no_argument,       NULL, 's' },
       { "exit-on-close",no_argument,       NULL, 'c' },
+      { "truecolor",    no_argument,       NULL, 't' },
       { NULL,           no_argument,       NULL,  0  }
     };
 
@@ -777,6 +784,8 @@ bool config_t::ProcessArgs(int argc, char *argv[])
               break;
     case 'f': ProcessArg("Fullscreen", "1");
               break;
+    case 't': ProcessArg("truecoloreverytime", "1");
+	      break;
     case 'D': ProcessArg("X11.HUDOSD", "1");
               if (optarg && strstr(optarg, "xshape")) {
                 ProcessArg("XShapeHUDOSD", "1");
@@ -860,6 +869,8 @@ bool config_t::ProcessArgs(int argc, char *argv[])
               break;
     case 'p': ProcessArg("ForcePrimaryDevice", "1");
               break;
+    case 's': ProcessArg("AutoSuspendOutput", "1");
+              break;
     case 'c': exit_on_close = 1;
               break;
 
@@ -884,6 +895,7 @@ bool config_t::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "Fullscreen"))         fullscreen = atoi(Value);
   else if (!strcasecmp(Name, "DisplayAspect"))      display_aspect = strstra(Value, s_aspects, 0);
   else if (!strcasecmp(Name, "ForcePrimaryDevice")) force_primary_device = atoi(Value);
+  else if (!strcasecmp(Name, "AutoSuspendOutput"))  use_suspendoutput = atoi(Value);
 
   else if (!strcasecmp(Name, "X11.WindowId"))     window_id = (!strcmp(Value, "root")) ? WINDOW_ID_ROOT : atoi(Value);
   else if (!strcasecmp(Name, "X11.WindowWidth"))  width = atoi(Value);
@@ -895,6 +907,7 @@ bool config_t::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "X11.OpenglAlways")) opengl = atoi(Value);
   else if (!strcasecmp(Name, "X11.OpenglHUDOSD")) hud_osd |= (atoi(Value) ? HUD_OPENGL : 0);
   else if (!strcasecmp(Name, "X11.XShapeHUDOSD")) hud_osd |= (atoi(Value) ? HUD_XSHAPE : 0);
+  else if (!strcasecmp(Name, "truecoloreverytime")) truecoloreverytime = atoi(Value);
 
   else if (!strcasecmp(Name, "Audio.Driver")) STRN0CPY(audio_driver, Value);
   else if (!strcasecmp(Name, "Audio.Port"))   STRN0CPY(audio_port, Value);
@@ -1031,6 +1044,7 @@ bool config_t::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "Media.DVD.ArrowKeysControlPlayback")) dvd_arrow_keys_control_playback = atoi(Value);
   else if (!strcasecmp(Name, "Media.MenuItems"))         media_menu_items = atoi(Value);
   else if (!strcasecmp(Name, "Media.EnableDelete"))      media_enable_delete = atoi(Value);
+  else if (!strcasecmp(Name, "Media.EnableResume"))      media_enable_resume = atoi(Value);
 
   else if (!strcasecmp(Name, "Playlist.Tracknumber")) playlist_tracknumber = atoi(Value);
   else if (!strcasecmp(Name, "Playlist.Artist"))      playlist_artist = atoi(Value);
