@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: config.h,v 1.90 2012/03/19 11:38:43 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -264,6 +264,9 @@ class config_t {
     // Force xineliboutput to be the primary device
     int  force_primary_device;
 
+    // Use vdr-suspendoutput: suspend when there are no clients
+    int  use_suspendoutput;
+
     // OSD state
     eMainMenuMode  main_menu_mode;      // used internally to open right sub-menu
     cOsdObject    *pending_menu_action; // used to replace current OSD with another type of OSD object
@@ -294,6 +297,7 @@ class config_t {
     int  window_id;        // use existing X11 window
     int  hud_osd;          // head up display OSD
     int  opengl;           // use opengl acceleration for video and HUD OSD
+    int  truecoloreverytime;
 
     // Audio settings
     int  speaker_type;
@@ -354,6 +358,7 @@ class config_t {
     int  dvd_arrow_keys_control_playback;
     uint media_menu_items;         // enabled items in media player menu (bitmask)
     int  media_enable_delete;      // enable Delete in file browser
+    int  media_enable_resume;
 
     // deinterlacing post plugin
     char deinterlace_method[32];
