@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: frontend_svr.c,v 1.107 2012/03/18 12:22:25 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -34,8 +34,8 @@
 #include "config.h"
 
 #include "xine_input_vdr_net.h"   // stream header(s)
-#include "xine_osd_command.h"     // osd commands
 
+#include "tools/osd_command.h"     // osd commands
 #include "tools/cxsocket.h"
 #include "tools/future.h"
 #include "tools/backgroundwriter.h"
@@ -45,6 +45,7 @@
 #include "tools/sdp.h"
 #include "tools/rle.h"
 #include "tools/sys_cap.h"
+#include "tools/avahi.h"
 
 #include "frontend_svr.h"
 #include "device.h"
@@ -136,6 +137,8 @@ cXinelibServer::cXinelibServer(cXinelibDevice *Dev, int listen_port) :
   m_Port = listen_port;
   m_ServerId = time(NULL) ^ getpid();
 
+  m_hAvahi = NULL;
+
   fd_listen    = -1;
   fd_discovery = -1;
 
@@ -184,6 +187,10 @@ cXinelibServer::~cXinelibServer()
   delete m_Scheduler;
 
   free(m_Header);
+
+  if (m_hAvahi) {
+    x_avahi_stop(m_hAvahi);
+  }
 }
 
 void cXinelibServer::Clear(void)
@@ -255,7 +262,7 @@ static int write_osd_command(cxSocket& s, osd_command_t *cmd)
   ssize_t max  = s.tx_buffer_free();
   ssize_t size = (ssize_t)8 +
                  (ssize_t)(sizeof(osd_command_t)) +
-                 (ssize_t)(sizeof(xine_clut_t) * ntohl(cmd->colors)) +
+                 (ssize_t)(sizeof(osd_clut_t) * ntohl(cmd->colors)) +
                  (ssize_t)(ntohl(cmd->datalen));
 
   if(max > 0 && max < MIN(size, 1024)) {
@@ -279,8 +286,8 @@ static int write_osd_command(cxSocket& s, osd_command_t *cmd)
     return -1;
   }
   if(cmd->palette && cmd->colors &&
-     (ssize_t)(sizeof(xine_clut_t)*ntohl(cmd->colors)) !=
-     s.write(cmd->palette, sizeof(xine_clut_t)*ntohl(cmd->colors), 100)) {
+     (ssize_t)(sizeof(osd_clut_t)*ntohl(cmd->colors)) !=
+     s.write(cmd->palette, sizeof(osd_clut_t)*ntohl(cmd->colors), 100)) {
     LOGDBG("write_osd_command: write (palette) failed");
     return -1;
   }
@@ -783,7 +790,7 @@ int cXinelibServer::SupportsTrueColorOSD(void)
         has_clients++;
     }
 
-  return has_clients ? 1 : -1;
+  return has_clients || xc.truecoloreverytime ? 1 : -1;
 }
 
 int cXinelibServer::PlayFileCtrl(const char *Cmd, int TimeoutMs)
@@ -822,6 +829,11 @@ bool cXinelibServer::Listen(int listen_port)
   bool result = false;
   TRACEF("cXinelibServer::Listen");
 
+  if (m_hAvahi) {
+    x_avahi_stop(m_hAvahi);
+    m_hAvahi = NULL;
+  }
+
   if(listen_port <= 0 || listen_port > 0xffff) {
     CLOSESOCKET(fd_listen);
     CLOSESOCKET(fd_discovery);
@@ -838,6 +850,7 @@ bool cXinelibServer::Listen(int listen_port)
 
     int iReuse = 1;
     struct sockaddr_in name;
+    memset(&name, 0, sizeof(name));
     name.sin_family = AF_INET;
     name.sin_addr.s_addr = htonl(INADDR_ANY);
     name.sin_port = htons(m_Port);
@@ -853,7 +866,12 @@ bool cXinelibServer::Listen(int listen_port)
       }
     }
     fd_listen = socket(PF_INET,SOCK_STREAM,0);
-    setsockopt(fd_listen, SOL_SOCKET, SO_REUSEADDR, &iReuse, sizeof(int));
+    if (fd_listen < 0) {
+      LOGERR("cXinelibServer: error creating listen socket");
+    } else {
+      if (setsockopt(fd_listen, SOL_SOCKET, SO_REUSEADDR, &iReuse, sizeof(int)) < 0) {
+        LOGERR("cXinelibServer: error setting REUSE for listen socket");
+      }
 
     if (bind(fd_listen, (struct sockaddr *)&name, sizeof(name)) < 0) {
       LOGERR("cXinelibServer: bind error %s port %d: %s",
@@ -868,6 +886,7 @@ bool cXinelibServer::Listen(int listen_port)
       LOGMSG("Listening on port %d", m_Port);
       result = true;
     }
+    }
   } else {
     result = true;
   }
@@ -876,24 +895,30 @@ bool cXinelibServer::Listen(int listen_port)
   CLOSESOCKET(fd_discovery);
   if(xc.remote_usebcast) {
     fd_discovery = udp_discovery_init();
-    if(udp_discovery_broadcast(fd_discovery, m_Port, xc.remote_local_ip) < 0)
-      CLOSESOCKET(fd_discovery);
-    else
-      LOGMSG("Listening for UDP broadcasts on port %d", m_Port);
+    if (fd_discovery >= 0) {
+      if(udp_discovery_broadcast(fd_discovery, m_Port, xc.remote_local_ip) < 0)
+        CLOSESOCKET(fd_discovery);
+      else
+        LOGMSG("Listening for UDP broadcasts on port %d", m_Port);
+    }
   }
 
   // set up multicast sockets
 
-  if(m_Scheduler)
+  if(m_Scheduler) {
     m_Scheduler->RemoveRtp();
 
-  if(xc.remote_usertp) {
-    if(xc.remote_rtp_always_on)
-      LOGMSG("WARNING: RTP Configuration: transmission is always on !");
-    if(xc.remote_rtp_always_on || m_iMulticastMask)
-      m_Scheduler->AddRtp();
+    if(xc.remote_usertp) {
+      if(xc.remote_rtp_always_on)
+        LOGMSG("WARNING: RTP Configuration: transmission is always on !");
+      if(xc.remote_rtp_always_on || m_iMulticastMask)
+        m_Scheduler->AddRtp();
+    }
   }
 
+  // AVAHI announces
+  m_hAvahi = x_avahi_start(listen_port, xc.remote_use_rtsp, xc.remote_use_http);
+
   return result;
 }
 
@@ -997,7 +1022,9 @@ void cXinelibServer::Handle_Control_PIPE(int cli, const char *arg)
     return;
   }
 
-  fcntl(fd, F_SETFL, fcntl(fd, F_GETFL)|O_NONBLOCK);
+  if (fcntl(fd, F_SETFL, fcntl(fd, F_GETFL)|O_NONBLOCK) < 0) {
+    LOGERR("error setting pipe to non-blocking mode");
+  }
 
   //LOGDBG("cXinelibServer::Handle_Control: pipe %s open", pipeName);
 
@@ -1472,8 +1499,8 @@ void cXinelibServer::Handle_Control_RTSP(int cli, const char *arg)
 
     if(!xc.remote_use_rtsp) {
       LOGMSG("RTSP transport disabled in configuration");
-      fd_control[cli].write_cmd(RTSP_401);
-      LOGDBG("HTTP Reply: HTTP/1.1 404 Not Found");
+      RTSPOUT(RTSP_401);
+      LOGDBG("RTSP Reply: HTTP/1.1 404 Not Found");
       CloseConnection(cli);
       return;
     }
@@ -1500,7 +1527,9 @@ void cXinelibServer::Handle_Control_RTSP(int cli, const char *arg)
         socklen_t len = sizeof(sin);
         char buf[64];
         uint32_t payload_type = VDRVERSNUM > 10702 ? SDP_PAYLOAD_MPEG_TS : SDP_PAYLOAD_MPEG_PES;
-        fd_control[cli].getsockname((struct sockaddr *)&sin, &len);
+        if (fd_control[cli].getsockname((struct sockaddr *)&sin, &len) < 0) {
+          LOGERR("Error getting control socket address");
+        }
         const char *sdp_descr = vdr_sdp_description(cxSocket::ip2txt(sin.sin_addr.s_addr,
                                                                      sin.sin_port, buf),
                                                     2001,
@@ -1516,7 +1545,9 @@ void cXinelibServer::Handle_Control_RTSP(int cli, const char *arg)
                 "Content-Length: %lu\r\n"
                 "\r\n",
                 CSeq, (unsigned long)sdplen);
-        fd_control[cli].write_cmd(sdp_descr, sdplen);
+        if (sdplen) {
+          fd_control[cli].write_cmd(sdp_descr, sdplen);
+        }
       } else {
         RTSPOUT(RTSP_415 /*UNSUPPORTED_MEDIATYPE*/);
       }
@@ -1758,7 +1789,7 @@ void cXinelibServer::Handle_ClientConnected(int fd)
     const char *msg = "Server busy.\r\n";
     ssize_t len = strlen(msg);
     // too many clients
-    LOGMSG("Too many clients, connection refused");
+    LOGMSG("Too many clients (%d), connection refused", cli);
     if(write(fd, msg, len) != len)
       LOGERR("Write failed.");
     CLOSESOCKET(fd);
@@ -1772,8 +1803,9 @@ void cXinelibServer::Handle_ClientConnected(int fd)
   }
 
   int alive = 1;
-  setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &alive, sizeof(alive));
-
+  if (setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &alive, sizeof(alive)) < 0) {
+    LOGERR("error setting SO_KEEPALIVE");
+  }
   CloseDataConnection(cli);
 
   m_OsdTimeouts[cli] = 0;
@@ -1826,8 +1858,7 @@ void cXinelibServer::Action(void)
 {
   TRACEF("cXinelibServer::Action");
 
-  int    i, fds=0;
-  pollfd pfd[MAXCLIENTS];
+  pollfd pfd[2*MAXCLIENTS + 2];
 
   /* higher priority */
   if (have_cap_sys_nice())
@@ -1855,9 +1886,9 @@ void cXinelibServer::Action(void)
   m_bReady=true;
 
   if(fd_listen>=0)
-    while (Running() && fds>=0) {
+    while (Running()) {
+      int i, fds = 0;
 
-      fds = 0;
       if(fd_listen>=0) {
         pfd[fds].fd = fd_listen;
         pfd[fds++].events = POLLIN;
