@@ -4,11 +4,21 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: logdefs.h,v 1.8 2008/02/05 01:18:17 phintuka Exp $
+ * $Id$
  *
  */
 
 #ifndef _LOGDEFS_H_
+#define _LOGDEFS_H_
+
+
+#if !defined(__GNUC__) || __GNUC__ < 3
+#  define LIKELY(x)   (x)
+#  define UNLIKELY(x) (x)
+#else
+#  define LIKELY(x)   __builtin_expect((x),1)
+#  define UNLIKELY(x) __builtin_expect((x),0)
+#endif
 
 /*
  * Default module name (goes to every log line)
@@ -22,51 +32,42 @@
  * Logging functions, should not be used directly
  */
 
-#if defined(esyslog) || (defined(VDRVERSNUM) && VDRVERSNUM >= 10343)
-#  define x_syslog(l,x...) syslog_with_tid(l, LOG_MODULENAME x)
+#include <syslog.h> /* logging levels: LOG_ERR, LOG_INFO, LOG_DEBUG */
+
+#define SYSLOGLEVEL_NONE    0
+#define SYSLOGLEVEL_ERRORS  1
+#define SYSLOGLEVEL_INFO    2
+#define SYSLOGLEVEL_DEBUG   3
+#define SYSLOGLEVEL_VERBOSE 4
+
+#if defined(esyslog)
+#  define x_syslog(l,m,x...) syslog_with_tid(l, m x)
 #else
 
-#  ifndef __APPLE__
-#    include <linux/unistd.h> /* syscall(__NR_gettid) */
+#  ifdef __cplusplus
+  extern "C" {
 #  endif
 
-   /* from xine_frontend.c or vdr tools.c: */
-   extern int SysLogLevel; /* errors, info, debug */
+  /* from xine_frontend.c or vdr/tools.c: */
+  extern int SysLogLevel; /* errors, info, debug */
 
-#  ifndef LogToSysLog
-   extern int LogToSysLog; /* xine_frontend_c, log to syslog instead of console */
+  /* from logdefs.c: */
+  extern int LogToSysLog;
+
+  void x_syslog(int level, const char *module, const char *fmt, ...)
+       __attribute__((format (printf, 3, 4)))
+       __attribute__((visibility("default")));
+
+#  ifdef __cplusplus
+  } /* extern "C" { */
 #  endif
 
-#  if defined(NEED_x_syslog)
-#    include <syslog.h>
-#    include <sys/syscall.h>
-#    include <stdarg.h>
-     static void x_syslog(int level, const char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
-     static void x_syslog(int level, const char *fmt, ...)
-     { 
-       va_list argp;
-       char buf[512];
-       va_start(argp, fmt);
-       vsnprintf(buf, 512, fmt, argp);
-       buf[sizeof(buf)-1] = 0;
-#    ifndef __APPLE__
-       if(!LogToSysLog) {
-	 fprintf(stderr,"[%ld] " LOG_MODULENAME "%s\n", (long int)syscall(__NR_gettid), buf);
-       } else {
-	 syslog(level, "[%ld] " LOG_MODULENAME "%s", (long int)syscall(__NR_gettid), buf);
-       }
-#    else
-       if(!LogToSysLog) {
-	 fprintf(stderr, LOG_MODULENAME "%s\n", buf);
-       } else {
-	 syslog(level, LOG_MODULENAME "%s", buf);
-       }
-#    endif
-       va_end(argp);
-     }
-#  endif /* NEED_x_syslog */
 #endif /* VDR */
 
+#ifdef NEED_x_syslog
+# error NEED_x_syslog is deprecated
+#endif
+
 
 /*
  * Macros used for logging
@@ -74,18 +75,33 @@
 
 #include <errno.h>
 
-#define LOG_ERRNO  x_syslog(LOG_ERR, "   (ERROR (%s,%d): %s)", \
-                   __FILE__, __LINE__, strerror(errno))
+#define LOG_ERRNO                                                     \
+        x_syslog(LOG_ERR, LOG_MODULENAME, "   (ERROR (%s,%d): %s)",   \
+                 __FILE__, __LINE__, strerror(errno))
 
-#define LOGERR(x...) do { \
-                       if(SysLogLevel > 0) { \
-                          x_syslog(LOG_ERR, x); \
-                          if(errno) \
-                            LOG_ERRNO; \
-                       } \
-                     } while(0)
-#define LOGMSG(x...) do{ if(SysLogLevel > 1) x_syslog(LOG_INFO,  x); } while(0)
-#define LOGDBG(x...) do{ if(SysLogLevel > 2) x_syslog(LOG_DEBUG, x); } while(0)
+#define LOGERR(x...)                                \
+        do {                                        \
+          if (LIKELY(SysLogLevel >= SYSLOGLEVEL_ERRORS)) {      \
+            x_syslog(LOG_ERR, LOG_MODULENAME, x);   \
+            if (errno)                              \
+              LOG_ERRNO;                            \
+          }                                         \
+        } while(0)
+#define LOGMSG(x...)                                \
+        do {                                        \
+          if (LIKELY(SysLogLevel >= SYSLOGLEVEL_INFO))  \
+            x_syslog(LOG_INFO, LOG_MODULENAME, x);  \
+        } while(0)
+#define LOGDBG(x...)                                \
+        do {                                        \
+          if (UNLIKELY(SysLogLevel >= SYSLOGLEVEL_DEBUG))       \
+            x_syslog(LOG_DEBUG, LOG_MODULENAME, x); \
+        } while(0)
+#define LOGVERBOSE(x...)                            \
+        do {                                        \
+          if (UNLIKELY(SysLogLevel >= SYSLOGLEVEL_VERBOSE))     \
+            x_syslog(LOG_DEBUG, LOG_MODULENAME, x); \
+        } while(0)
 
 #define TRACELINE LOGDBG("at %s:%d %s", __FILE__, __LINE__, __FUNCTION__)
 
@@ -100,7 +116,7 @@
 #else
 #  define ASSERT(expr,fatal) \
       do { \
-        if(!(expr)) { \
+        if(UNLIKELY(!(expr))) {                         \
           LOGERR("Asseretion failed: %s at %s:%d (%s)", \
                  #expr, __FILE__, __LINE__, __FUNCTION__); \
           if(fatal) \
@@ -109,6 +125,15 @@
       } while(0)
 #endif
 
+#define ASSERT_RET(expr,ret) \
+      do { \
+        if(UNLIKELY(!(expr))) {                         \
+          LOGMSG("Asseretion failed: %s at %s:%d (%s)", \
+                 #expr, __FILE__, __LINE__, __FUNCTION__); \
+          ret; \
+        } \
+      } while(0)
+
 
 /*
  * Plugin (call)trace
