@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: media_player.c,v 1.94 2012/08/29 19:25:14 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -96,7 +96,7 @@ class cXinelibPlayer : public cPlayer
 cXinelibPlayer::cXinelibPlayer(cXinelibDevice *Dev, const char *File, bool Queue, const char *SubFile)
 {
   m_ResumeFile = NULL;
-  m_UseResumeFile = true;
+  m_UseResumeFile = xc.media_enable_resume;
   m_Error = false;
   m_Speed = 1;
   m_Dev = Dev;
@@ -547,7 +547,7 @@ cXinelibPlayerControl::cXinelibPlayerControl(cXinelibDevice *Dev, eMainMenuMode
   number = 0;
   lastTime.Set();
 
-  m_Player->UseResumeFile( (Mode==ShowFiles) );
+  m_Player->UseResumeFile( (Mode==ShowFiles) && xc.media_enable_resume);
 
   MsgReplaying(*m_Player->Playlist().Current()->Title, *m_Player->File());
 }
@@ -751,6 +751,7 @@ eOSState cXinelibPlayerControl::ProcessKey(eKeys Key)
       case kUser9:
       case k3:      m_Player->Control("SEEK +20");  break;
       case k2:      xc.subtitle_vpos -= 10;
+                    /* fall thru */
       case k5:      xc.subtitle_vpos += 5;
                     m_Player->Control("SUBTITLES %d", xc.subtitle_vpos);
                     break;
