@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: menu.c,v 1.96 2012/03/19 11:29:14 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -220,7 +220,11 @@ void cMenuBrowseFiles::Set(void)
   }
 
   if (m_CurrentDir[0] != '/') {
+#if defined(APIVERSNUM) && (APIVERSNUM < 20102)
     m_CurrentDir = VideoDirectory;
+#else
+    m_CurrentDir = cVideoDirectory::Name();
+#endif
   }
 
   // find deepest accessible directory from path
@@ -585,6 +589,11 @@ cMenuXinelib::cMenuXinelib(cXinelibDevice *Dev)
 
   novideo = m_Dev->GetPlayMode() == pmAudioOnlyBlack ? 1 : 0;
 
+  audio_ctrl_compress = NULL;
+  ctrl_autocrop = NULL;
+  ctrl_overscan = NULL;
+  ctrl_novideo = NULL;
+
   Add(SeparatorItem(tr("Media")));
   if (xc.media_menu_items & MEDIA_MENU_FILES)
     Add(SubMenuItem(tr("Play file"),        osUser1));
