@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: osd.c,v 1.48 2011/03/20 23:04:47 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -15,7 +15,8 @@
 #include "logdefs.h"
 #include "config.h"
 #include "device.h"
-#include "xine_osd_command.h"
+
+#include "tools/osd_command.h"
 
 #include "osd.h"
 
@@ -36,7 +37,7 @@ static inline int saturate(int x, int min, int max)
   return x < min ? min : (x > max ? max : x);
 }
 
-static inline void prepare_palette(xine_clut_t *clut, const unsigned int *palette, int colors, bool top, bool rgb)
+static inline void prepare_palette(osd_clut_t *clut, const unsigned int *palette, int colors, bool top, bool rgb)
 {
   if (colors) {
     int c;
@@ -251,7 +252,7 @@ void cXinelibOsd::CmdPalette(int Wnd, int Colors, unsigned int *Palette)
   TRACEF("cXinelibOsd::CmdPalette");
 
   if (m_Device) {
-    xine_clut_t   clut[Colors];
+    osd_clut_t    clut[Colors];
     osd_command_t osdcmd = {0};
 
     osdcmd.cmd     = OSD_SetPalette;
@@ -310,8 +311,7 @@ void cXinelibOsd::SetCmdFlags(osd_command_t& cmd)
 
   cmd.scaling = xc.osd_scaling;
 
-  if ((VDRVERSNUM < 10717 && m_Layer == OSD_LEVEL_SUBTITLES) ||
-      (                      m_Layer == OSD_LEVEL_TTXTSUBS))
+  if (m_Layer == OSD_LEVEL_TTXTSUBS)
     cmd.scaling = xc.osd_spu_scaling;
 }
 
@@ -354,7 +354,7 @@ void cXinelibOsd::CmdLut8(int Wnd, int X0, int Y0,
 
   if (m_Device) {
 
-    xine_clut_t   clut[Colors];
+    osd_clut_t    clut[Colors];
     osd_command_t osdcmd = {0};
 
     osdcmd.cmd   = OSD_Set_LUT8;
@@ -434,10 +434,7 @@ eOsdError cXinelibOsd::SetAreas(const tArea *Areas, int NumAreas)
     return oeTooManyAreas;
   }
 
-#if VDRVERSNUM >= 10708
-  if (xc.osd_spu_scaling &&
-      ((VDRVERSNUM < 10717 && m_Layer == OSD_LEVEL_SUBTITLES) ||
-       (                      m_Layer == OSD_LEVEL_TTXTSUBS))) {
+  if (xc.osd_spu_scaling && m_Layer == OSD_LEVEL_TTXTSUBS) {
     m_ExtentWidth  = 720;
     m_ExtentHeight = 576;
   } else {
@@ -448,22 +445,6 @@ eOsdError cXinelibOsd::SetAreas(const tArea *Areas, int NumAreas)
     m_ExtentHeight = H;
   }
 
-#else
-
-  // Detect full OSD area size
-  if(Left() + Width() > 720 || Top() + Height() > 576) {
-    m_ExtentWidth  = Setup.OSDWidth  + 2 * Setup.OSDLeft;
-    m_ExtentHeight = Setup.OSDHeight + 2 * Setup.OSDTop;
-    LOGDBG("Detected HD OSD, size > %dx%d, using setup values %dx%d",
-           2*Left() + Width(), 2*Top() + Height(),
-           m_ExtentWidth, m_ExtentHeight);
-  } else {
-    m_ExtentWidth  = 720;
-    m_ExtentHeight = 576;
-  }
-
-#endif
-
   CmdSize(m_ExtentWidth, m_ExtentHeight);
 
   return Result;
@@ -526,32 +507,32 @@ void cXinelibOsd::Flush(void)
   if(!m_IsVisible)
     return;
 
-#ifdef YAEPGHDVERSNUM
-  if (vidWin.bpp)
-    CmdVideoWindow(vidWin.x1, vidWin.y1, vidWin.Width(), vidWin.Height());
-#endif
+  const cRect& videoWindow = m_Device->GetVideoWindow();
+  if (videoWindow != cRect::Null) {
+    CmdVideoWindow(videoWindow.X(), videoWindow.Y(), videoWindow.Width(), videoWindow.Height());
+  }
 
-#if VDRVERSNUM >= 10717
   if (IsTrueColor()) {
 
     LOCK_PIXMAPS;
-    while (cPixmapMemory *pm = RenderPixmaps()) {
+    while (cPixmapMemory *pm = dynamic_cast<cPixmapMemory*>(RenderPixmaps())) {
       int w = pm->ViewPort().Width();
       int h = pm->ViewPort().Height();
       int d = w * sizeof(tColor);
       CmdArgb(Left() + pm->ViewPort().X(), Top() + pm->ViewPort().Y(), w, h, pm->Data(), h * d);
+#if VDRVERSNUM >= 20200
+      DestroyPixmap(pm);
+#else
       delete pm;
+#endif
     }
 
     return;
   }
-#endif
 
   int SendDone = 0, XOffset = 0, YOffset = 0;
 
-  if (!xc.osd_spu_scaling &&
-      ((VDRVERSNUM < 10717 && m_Layer == OSD_LEVEL_SUBTITLES) ||
-       (                      m_Layer == OSD_LEVEL_TTXTSUBS))) {
+  if (!xc.osd_spu_scaling && m_Layer == OSD_LEVEL_TTXTSUBS) {
     double Aspect;
     int    W, H;
     m_Device->GetOsdSize(W, H, Aspect);
@@ -567,7 +548,7 @@ void cXinelibOsd::Flush(void)
       int NumColors;
       const tColor *Colors = Bitmap->Colors(NumColors);
       if (Colors) {
-	osd_rect_t DirtyArea = {x1:x1, y1:y1, x2:x2, y2:y2};
+	osd_rect_t DirtyArea = {x1:(uint16_t)x1, y1:(uint16_t)y1, x2:(uint16_t)x2, y2:(uint16_t)y2};
         CmdLut8(i,
                 Left() + Bitmap->X0() + XOffset, Top() + Bitmap->Y0() + YOffset,
                 Bitmap->Width(), Bitmap->Height(),
