@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: bitstream.h,v 1.3 2009/02/14 20:44:15 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -16,15 +16,15 @@
 
 typedef struct {
   const uint8_t *data;
-  int            count; /* in bits */
-  int            index; /* in bits */
+  size_t         count; /* in bits */
+  size_t         index; /* in bits */
 } br_state;
 
 #define BR_INIT(data,bytes) { (data), 8*(bytes), 0 }
 
 #define BR_EOF(br) ((br)->index >= (br)->count)
 
-static inline void br_init(br_state *br, const uint8_t *data, int bytes)
+static inline void br_init(br_state *br, const uint8_t *data, size_t bytes)
 {
   br->data  = data;
   br->count = 8*bytes;
@@ -61,15 +61,15 @@ static inline void br_skip_bits(br_state *br, int n)
 
 
 typedef struct {
-  uint8_t *data;
-  uint8_t *data_end;
-  uint32_t cache; 
+  const uint8_t *data;
+  const uint8_t *data_end;
+  uint32_t cache;
   uint32_t cache_bits;
 } br_state;
 
 #define BR_INIT(data,bytes) { (data), (data)+(bytes), 0, 0 }
 
-static inline void br_init(br_state *br, const uint8_t *data, int bytes)
+static inline void br_init(br_state *br, const uint8_t *data, size_t bytes)
 {
   br->data       = data;
   br->data_end   = data + bytes;
@@ -124,7 +124,7 @@ static inline void br_skip_bits(br_state *br, int n)
   } else {
     /* drop cached bits */
     n -= br->cache_bits;
-  
+
     /* drop full bytes */
     br->data += (n >> 3);
     n &= 7;
@@ -138,7 +138,7 @@ static inline void br_skip_bits(br_state *br, int n)
     }
   }
 }
- 
+
 
 # endif /* NOCACHE */
 
