@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: http.c,v 1.6 2007/06/21 09:12:52 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -284,7 +284,18 @@ bool cHttpStreamer::Seek(void)
     m_fds.write_cmd(HTTP_REPLY_416); // 416 Requested Range Not Satisfiable
     return false;
   }
-  
+
+  bool result;
+  if (m_Start > 0)
+    result = (lseek(m_fdf, (off_t)m_Start, SEEK_SET) == (off_t)m_Start);
+  else
+    result = (lseek(m_fdf, 0, SEEK_SET) == 0);
+  if (!result) {
+    LOGERR("cHttpStreamer: error seeking to %" PRId64, m_Start);
+    m_fds.write_cmd(HTTP_REPLY_416); // 416 Requested Range Not Satisfiable
+    return false;
+  }
+
   if(m_Start > 0) {
     if(m_End >= m_FileSize || m_End < 0)
       m_End = m_FileSize-1;
@@ -297,7 +308,7 @@ bool cHttpStreamer::Seek(void)
   }
 
   /* content type */
-  char *ext = strrchr(m_Filename, '.');
+  const char *ext = strrchr(m_Filename, '.');
   if(ext) {
     const char *mime = mimetype(ext+1);
     if(mime)
@@ -322,11 +333,6 @@ bool cHttpStreamer::Seek(void)
     m_fds.write_cmd("Connection: Close\r\n"
 		    "\r\n");
 
-  if(m_Start)
-    lseek(m_fdf, (off_t)m_Start, SEEK_SET);
-  else
-    lseek(m_fdf, 0, SEEK_SET);
-
   return true;
 }
 
@@ -369,7 +375,7 @@ void cHttpStreamer::Action(void)
   int      n = 0;
   cxPoller p(m_fds);
   bool     Disc = !(ParseRequest() && Seek());
-  uint64_t pos  = m_Start;
+  //uint64_t pos  = m_Start;
   off_t    start = (off_t)m_Start;
 
   while(Running() && !Disc) {
@@ -415,7 +421,7 @@ void cHttpStreamer::Action(void)
 	LOGDBG("cHttpStreamer: Reading pipelined request");
 	pthread_testcancel();
 	Disc = !(ReadPipelined() && ParseRequest() && Seek());
-	pos = m_Start;
+	//pos = m_Start;
       }
     } while(--n && Running() && !Disc);
 
