@@ -4,71 +4,74 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: pes.c,v 1.2.2.1 2008/09/26 19:08:25 phintuka Exp $
+ * $Id$
  *
  */
 
+#include <inttypes.h>
+#include <string.h>
+
+#include "../logdefs.h"
+
 #include "mpeg.h"
 #include "h264.h"
 
 #include "pes.h"
 
+static int64_t parse_timestamp(const uint8_t *buf)
+{
+  int64_t ts;
+  ts  = ((int64_t)( buf[0] & 0x0E)) << 29 ;
+  ts |=  (int64_t)( buf[1]         << 22 );
+  ts |=  (int64_t)((buf[2] & 0xFE) << 14 );
+  ts |=  (int64_t)( buf[3]         <<  7 );
+  ts |=  (int64_t)((buf[4] & 0xFE) >>  1 );
+  return ts;
+}
 
 int64_t pes_get_pts(const uint8_t *buf, int len)
 {
   /* assume mpeg2 pes header ... */
   if (IS_VIDEO_PACKET(buf) || IS_AUDIO_PACKET(buf)) {
-      
+
     if ((buf[6] & 0xC0) != 0x80)
-      return INT64_C(-1);
+      return NO_PTS;
     if ((buf[6] & 0x30) != 0)
-      return INT64_C(-1);
-      
+      return NO_PTS;
+
     if ((len > 13) && (buf[7] & 0x80)) { /* pts avail */
-      int64_t pts;
-      pts  = ((int64_t)(buf[ 9] & 0x0E)) << 29 ;
-      pts |= ((int64_t) buf[10])         << 22 ;
-      pts |= ((int64_t)(buf[11] & 0xFE)) << 14 ;
-      pts |= ((int64_t) buf[12])         <<  7 ;
-      pts |= ((int64_t)(buf[13] & 0xFE)) >>  1 ;
-      return pts;
+      return parse_timestamp(buf + 9);
     }
   }
-  return INT64_C(-1);
+  return NO_PTS;
 }
 
 int64_t pes_get_dts(const uint8_t *buf, int len)
 {
   if (IS_VIDEO_PACKET(buf) || IS_AUDIO_PACKET(buf)) {
-      
+
     if ((buf[6] & 0xC0) != 0x80)
-      return INT64_C(-1);
+      return NO_PTS;
     if ((buf[6] & 0x30) != 0)
-      return INT64_C(-1);
+      return NO_PTS;
 
     if (len > 18 && (buf[7] & 0x40)) { /* dts avail */
-      int64_t dts;
-      dts  = ((int64_t)( buf[14] & 0x0E)) << 29 ;
-      dts |=  (int64_t)( buf[15]         << 22 );
-      dts |=  (int64_t)((buf[16] & 0xFE) << 14 );
-      dts |=  (int64_t)( buf[17]         <<  7 );
-      dts |=  (int64_t)((buf[18] & 0xFE) >>  1 );
-      return dts;
+      return parse_timestamp(buf + 14);
     }
   }
-  return INT64_C(-1);
+  return NO_PTS;
 }
 
 void pes_change_pts(uint8_t *buf, int len, int64_t new_pts)
 {
   /* assume mpeg2 pes header ... Assume header already HAS pts */
   if (IS_VIDEO_PACKET(buf) || IS_AUDIO_PACKET(buf)) {
-      
+
     if ((buf[6] & 0xC0) != 0x80)
       return;
     if ((buf[6] & 0x30) != 0)
       return;
-      
+
     if ((len > 13) && (buf[7] & 0x80)) { /* pts avail */
       buf[ 9] = ((new_pts >> 29) & 0x0E) | (buf[ 9] & 0xf1);
       buf[10] = ((new_pts >> 22) & 0xFF);
@@ -111,42 +114,37 @@ int pes_is_frame_h264(const uint8_t *buf, int len)
 
   buf += 9 + buf[8];
 
-  if (!buf[0] && !buf[1] && buf[2] == 0x01 && buf[3] == 0x09)
+  if (IS_NAL_AUD(buf))
     return 1;
   return 0;
 }
 
 uint8_t pes_get_picture_type(const uint8_t *buf, int len)
 {
-  int i = 8;         /* the minimum length of the video packet header */
-  i += buf[i] + 1;   /* possible additional header bytes */
+  int i = PES_HEADER_LEN(buf);
 
   buf += i;
   len -= i;
 
-  if (!buf[0] && !buf[1] && buf[2]) {
-    if (buf[3] == 0x09)
+  if (buf[0] == 0x00 && buf[1] == 0x00 && buf[2] == 0x01) {
+    if (buf[3] == NAL_AUD)
       return h264_get_picture_type(buf, len);
-    else
-      return mpeg2_get_picture_type(buf, len);
+    return mpeg2_get_picture_type(buf, len);
   }
+
   return NO_PICTURE;
 }
 
 int pes_get_video_size(const uint8_t *buf, int len, video_size_t *size, int h264)
 {
-  int i = 8;
-
-  i += buf[i] + 1;   /* possible additional header bytes */
+  int i = PES_HEADER_LEN(buf);
 
   buf += i;
   len -= i;
 
-  if (h264 || (!buf[0] && !buf[1] && buf[2] == 0x01 && buf[3] == 0x09))
+  if (h264 || IS_NAL_AUD(buf))
     return h264_get_video_size(buf, len, size);
-  else
-    return mpeg2_get_video_size(buf, len, size);
 
-  return 0;
+  return mpeg2_get_video_size(buf, len, size);
 }
 
