@@ -4,14 +4,16 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: pes.h,v 1.6 2008/02/04 23:59:30 phintuka Exp $
+ * $Id$
  *
  */
 
-#ifndef _PES_H_
-#define _PES_H_
+#ifndef _XINELIBOUTPUT_PES_H_
+#define _XINELIBOUTPUT_PES_H_
 
-#include "mpeg.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 
 /*
@@ -22,6 +24,8 @@
 
 #define MAX_SCR ((int64_t)0x1ffffffffLL)
 
+#define NO_PTS  (INT64_C(-1))
+
 /* PES PIDs */
 #define PRIVATE_STREAM1   0xBD
 #define PADDING_STREAM    0xBE
@@ -42,17 +46,26 @@
 #define ISO13522_STREAM   0xF3
 #define PROG_STREAM_DIR   0xFF
 
-#define IS_VIDEO_PACKET(data)  (VIDEO_STREAM == ((data)[3] & ~VIDEO_STREAM_MASK))
-#define IS_AUDIO_PACKET(data) ((AUDIO_STREAM == ((data)[3] & ~AUDIO_STREAM_MASK)) || \
-                               (PRIVATE_STREAM1 == (data)[3]))
+#define IS_VIDEO_PACKET(data)      (VIDEO_STREAM    == ((data)[3] & ~VIDEO_STREAM_MASK))
+#define IS_MPEG_AUDIO_PACKET(data) (AUDIO_STREAM    == ((data)[3] & ~AUDIO_STREAM_MASK))
+#define IS_PS1_PACKET(data)        (PRIVATE_STREAM1 == (data)[3])
+#define IS_PADDING_PACKET(data)    (PADDING_STREAM  == (data)[3])
+#define IS_AUDIO_PACKET(data)      (IS_MPEG_AUDIO_PACKET(data) || IS_PS1_PACKET(data))
 
 #define PES_HAS_PTS(data)     ((data)[7] & 0x80)
 #define PES_HAS_DTS(data)     ((data)[7] & 0x40)
 
+#define DATA_IS_PES(data) (!(data)[0] && !(data)[1] && (data)[2] == 1)
+
+#define PES_HEADER_LEN(data) (8 + (data)[8] + 1)
+
+
 /*
  * timestamps
  */
 
+static inline int     pts_to_ms(int64_t pts) { return (int)(pts/INT64_C(90)); }
+static inline int64_t ms_to_pts(int ms)      { return ((int64_t)(ms)) * INT64_C(90); }
 
 int64_t pes_get_pts(const uint8_t *buf, int len);
 int64_t pes_get_dts(const uint8_t *buf, int len);
@@ -63,9 +76,11 @@ int     pes_strip_pts_dts(uint8_t *buf, int len);
  * payload
  */
 
+struct video_size_s;
+
 int     pes_is_frame_h264(const uint8_t *buf, int len);
 uint8_t pes_get_picture_type(const uint8_t *buf, int len);
-int     pes_get_video_size(const uint8_t *buf, int len, video_size_t *size, int h264);
+int     pes_get_video_size(const uint8_t *buf, int len, struct video_size_s *size, int h264);
 
 static inline int pes_is_mpeg1(const uint8_t *header)
 {
@@ -98,4 +113,8 @@ static inline int pes_packet_len(const uint8_t *data, const int len)
 }
 
 
-#endif /* _PES_H_ */
+#ifdef __cplusplus
+} /* extern "C" { */
+#endif
+
+#endif /* _XINELIBOUTPUT_PES_H_ */
