@@ -4,18 +4,20 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: playlist.c,v 1.17.2.2 2009/02/12 11:20:24 phintuka Exp $
+ * $Id$
  *
  */
 
+#include "../features.h"
+
 #include <stdlib.h> 
 
-#ifdef HAVE_EXTRACTOR_H
+#ifdef HAVE_LIBEXTRACTOR
 # include <extractor.h>
   // libextractor 0.5.20 (2008-03-20) adds support for track numbers
 # if EXTRACTOR_VERSION < 0x00052000
 #  warning libextractor version too old (0.5.20 required for track numbers)
-#  undef HAVE_EXTRACTOR_H
+#  undef HAVE_LIBEXTRACTOR
 # endif
 #endif
 
@@ -36,6 +38,12 @@
 
 #define MAX_PLAYLIST_FILES 1024
 
+static void strip_extension(cString& fname)
+{
+  const char *ext = strrchr(fname, '.');
+  if (ext)
+    fname.Truncate(ext - fname);
+}
 
 //
 // cPlaylistItem
@@ -43,7 +51,7 @@
 
 cPlaylistItem::cPlaylistItem(const char *filename)
 {
-  char *pt;
+  const char *pt;
 
   Filename = filename;
   Position = -1;
@@ -52,9 +60,8 @@ cPlaylistItem::cPlaylistItem(const char *filename)
     Title = pt + 1;
   else
     Title = filename;
-  
-  if(NULL != (pt = strrchr(Title, '.')))
-    *pt = 0;
+
+  strip_extension(Title);
 }
 
 cPlaylistItem::cPlaylistItem(const char *filename, 
@@ -62,8 +69,6 @@ cPlaylistItem::cPlaylistItem(const char *filename,
 			     const char *title, 
 			     int position)
 {
-  char *pt;
-
   if(path[strlen(path)-1] != '/')
     Filename = cString::sprintf("%s/%s", path, filename);
   else
@@ -71,8 +76,8 @@ cPlaylistItem::cPlaylistItem(const char *filename,
   Position = position;
   Title = title ?: filename;
 
-  if(!title && (pt = strrchr(Title, '.')))
-    *pt = 0;
+  if (!title)
+    strip_extension(Title);
 }
 
 int cPlaylistItem::Compare(const cListObject &ListObject) const 
@@ -107,7 +112,7 @@ int cPlaylistItem::Compare(const cListObject &ListObject) const
 // cID3Scanner
 //
 
-#ifndef HAVE_EXTRACTOR_H
+#ifndef HAVE_LIBEXTRACTOR
 static const char *shell_escape(char *buf, int buflen, const cString& src, char ch)
 {
   const char *pt = *src;
@@ -127,6 +132,39 @@ static const char *shell_escape(char *buf, int buflen, const cString& src, char
 }
 #endif
 
+#if defined(HAVE_LIBEXTRACTOR) && EXTRACTOR_VERSION >= 0x00060000
+static int extractor_callback_id3(void *priv,
+                                  const char *plugin_name,
+                                  enum EXTRACTOR_MetaType type,
+                                  enum EXTRACTOR_MetaFormat format,
+                                  const char *data_mime_type,
+                                  const char *data,
+                                  size_t data_len)
+{
+  if (format == EXTRACTOR_METAFORMAT_UTF8) {
+    cPlaylistItem *Item = (cPlaylistItem *)priv;
+    switch (type) {
+      case EXTRACTOR_METATYPE_TITLE:
+        Item->Title = data;
+        break;
+      case EXTRACTOR_METATYPE_ARTIST:
+        Item->Artist = data;
+        break;
+      case EXTRACTOR_METATYPE_ALBUM:
+        Item->Album = data;
+        break;
+      case EXTRACTOR_METATYPE_TRACK_NUMBER:
+        Item->Tracknumber = strlen(data) == 1 ? *cString::sprintf("0%s", data) : data;
+        break;
+      default:
+        break;
+    }
+  }
+  return 0;
+}
+#endif // defined(HAVE_LIBEXTRACTOR) && EXTRACTOR_VERSION >= 0x00060000
+
+
 class cID3Scanner : public cThread 
 {
  public:
@@ -163,7 +201,13 @@ class cID3Scanner : public cThread
 
       if(xc.IsAudioFile(Item->Filename)) {
         LOGDBG("Scanning metainfo for file %s", *Item->Filename);
-#ifdef HAVE_EXTRACTOR_H
+#ifdef HAVE_LIBEXTRACTOR
+#  if EXTRACTOR_VERSION >= 0x00060000
+	EXTRACTOR_PluginList * plugins;
+	plugins = EXTRACTOR_plugin_add_defaults(EXTRACTOR_OPTION_DEFAULT_POLICY);
+	EXTRACTOR_extract(plugins, *Item->Filename, NULL, 0, (EXTRACTOR_MetaDataProcessor)&extractor_callback_id3, Item);
+	EXTRACTOR_plugin_remove_all(plugins); /* unload plugins */
+#  else // EXTRACTOR_VERSION >= 0x00060000
         EXTRACTOR_ExtractorList * plugins;
         EXTRACTOR_KeywordList   * md_list;
         plugins = EXTRACTOR_loadDefaultLibraries();
@@ -172,11 +216,11 @@ class cID3Scanner : public cThread
         while(md_list) {
           if ((key=EXTRACTOR_getKeywordTypeAsString(md_list->keywordType))) {
             if (!strcasecmp(key,"title"))
-             Item->Title =  strdup(md_list->keyword);
+              Item->Title = md_list->keyword;
             else if (!strcasecmp(key,"artist"))
-             Item->Artist =  strdup(md_list->keyword);
+              Item->Artist = md_list->keyword;
             else if (!strcasecmp(key,"album"))
-             Item->Album =  strdup(md_list->keyword);
+              Item->Album = md_list->keyword;
             else if (!strcasecmp(key,"track number"))
              Item->Tracknumber = cString::sprintf("%s%s", strlen(md_list->keyword) == 1 ? "0" : "", md_list->keyword);
             md_list=md_list->next; 
@@ -184,7 +228,8 @@ class cID3Scanner : public cThread
          }
         EXTRACTOR_freeKeywords(md_list);
         EXTRACTOR_removeAll(plugins); /* unload plugins */
-#else
+#  endif // EXTRACTOR_VERSION >= 0x00060000
+#else // HAVE_LIBEXTRACTOR
         char buf[4096];
         cString Cmd = "";
         if(!strcasecmp((Item->Filename) + strlen(Item->Filename) - 5, ".flac"))
@@ -219,7 +264,7 @@ class cID3Scanner : public cThread
               Item->Tracknumber = cString::sprintf("%s%s", strlen(pt) == 13 ? "0" : "", (pt+12));
           }
         }
-#endif
+#endif // HAVE_LIBEXTRACTOR
       }
     }
     LOGDBG("ID3Scanner Done.");
@@ -245,7 +290,7 @@ class cPlaylistReader
   cPlaylistItem *Prev(void) { return m_Playlist.Last(); }
 
  public:
-  cPlaylistReader(cPlaylist& Playlist) : m_Playlist(Playlist) {}
+ cPlaylistReader(cPlaylist& Playlist) : m_Playlist(Playlist), m_Position(-1) {}
   virtual ~cPlaylistReader() {}
 
   virtual char *Parse(char *line) = 0;
@@ -302,9 +347,9 @@ class cPlsReader : public cPlaylistReader
 	      1 == sscanf(line + 5, "%d=", &n)) {
 	if(*(t+1)) {
 	  if(n == m_Current)
-	    Prev()->Title = t;
+	    Prev()->Title = t+1;
 	  else
-	    m_Title = t;
+	    m_Title = t+1;
 	}
       }
       //else if(!strncasecmp(line, "length", 6) && 
@@ -446,6 +491,17 @@ void cPlaylist::Del(cPlaylistItem *it)
   m_Version++;
 }
 
+void cPlaylist::Move(int From, int To)
+{
+  cMutexLock ml(&m_Lock);
+
+  if (Count() < 3)
+    return;
+
+  cListBase::Move(From, To);
+  m_Version++;
+}
+
 void cPlaylist::SetCurrent(cPlaylistItem *current) 
 {
   cMutexLock ml(&m_Lock);
@@ -468,6 +524,24 @@ cPlaylistItem *cPlaylist::Prev(void)
   return NULL;
 }
 
+cPlaylistItem *cPlaylist::Seek(int Rel)
+{
+  cMutexLock ml(&m_Lock);
+  if (!Current())
+    return NULL;
+
+  if (Rel > 0) {
+    while (Rel--)
+      m_Current = (cList<cPlaylistItem>::Next(Current()) ?: Last());
+
+  } else if (Rel < 0) {
+    while (Rel++)
+      m_Current = (cList<cPlaylistItem>::Prev(Current()) ?: First());
+  }
+
+  return Current();
+}
+
 bool cPlaylist::StoreCache(void) 
 {
   if(!xc.cache_implicit_playlists ||
@@ -531,7 +605,7 @@ bool cPlaylist::ReadCache(void)
       int len = strlen(m_Folder);
       cPlaylistItem *it = NULL;
       cReadLine r;
-      char *pt;
+      const char *pt;
       while(NULL != (pt = r.Read(f))) {
 	if(!strncmp(pt, "File", 4)) {
 	  it = NULL;
@@ -629,7 +703,7 @@ static FILE *open_http(const char *PlaylistFile)
 
 int cPlaylist::ScanFolder(const char *FolderName, 
 			  bool Recursive,
-			  bool (config_t::*Filter)(const char *))
+			  bool (*Filter)(const char *))
 {
   cMutexLock ml(&m_Lock);  
   static int depth = 0;
@@ -671,7 +745,7 @@ int cPlaylist::ScanFolder(const char *FolderName,
 	    if (stat(Buffer, &st) != 0)
 	      continue;
 	  }
-	  if((xc.*Filter)(Buffer)) {
+	  if((*Filter)(Buffer)) {
 	    /* TODO: Should ScanDir add contents of playlist files ... ? */
 	    if(Filter == &config_t::IsPlaylistFile || !xc.IsPlaylistFile(Buffer)) {
 	      n++;
@@ -762,29 +836,26 @@ int cPlaylist::ReadPlaylist(const char *file)
   
   if(f) {
     LOGDBG("cPlaylist: parsing %s", file);
-    char *pt = strrchr(file, '.');
-    if(!strcasecmp(pt, ".pls"))
+    const char *ext = strrchr(file, '.');
+    if(ext && !strcasecmp(ext, ".pls"))
       parser = new cPlsReader(*this);
-    else if(!strcasecmp(pt, ".asx"))
+    else if(ext && !strcasecmp(ext, ".asx"))
       parser = new cAsxReader(*this);
-    else /*if(!strcasecmp(pt, ".m3u"))*/
+    else /*if(!strcasecmp(ext, ".m3u"))*/
       parser = new cM3uReader(*this); /* parses plain lists (.ram, ...) too ...*/
 
-    cString Base(file);
-    if(NULL != (pt=strrchr(Base,'/')))
-      pt[1]=0;
+    /* get folder */
+    cString Folder = file;
+    const char *folder = strrchr(Folder, '/');
+    if (folder)
+      Folder.Truncate(folder - Folder + 1);
 
     int n = 0;
     cReadLine r;
+    char *pt;
     while(NULL != (pt = r.Read(f)) && n < MAX_PLAYLIST_FILES) {
       if(NULL != (pt = parser->Parse(pt))) {
 
-	if(depth && n==0) {
-	  // TODO
-	  //  - add "separator" item
-	  // Add(new cPlaylistItem(NULL, Base, "---");
-	}
-
 	if(xc.IsPlaylistFile(pt)) {
 	  parser->ResetCache();
 	  LOGDBG("cPlaylist: found playlist inside playlist");
@@ -797,7 +868,7 @@ int cPlaylist::ReadPlaylist(const char *file)
 		strchr(pt,'/') - pt < 8))
 	      n += ReadPlaylist(pt);
 	    else
-	      n += ReadPlaylist(cString::sprintf("%s%s", *Base, pt));
+	      n += ReadPlaylist(cString::sprintf("%s%s", *Folder, pt));
 	    depth--;
 	  }
 
@@ -811,7 +882,7 @@ int cPlaylist::ReadPlaylist(const char *file)
 	      Last()->Title = parser->Title();
 	  } else {
 	    // relative path
-	    Add(new cPlaylistItem(pt, Base, parser->Title()));
+	    Add(new cPlaylistItem(pt, Folder, parser->Title()));
 	  }
 	  Last()->Position = parser->Position();
 	  parser->ResetCache();
@@ -827,6 +898,9 @@ int cPlaylist::ReadPlaylist(const char *file)
     if(n >= MAX_PLAYLIST_FILES) 
       LOGMSG("cPlaylist: Found over %d matching files, list truncated!", n);
     LOGDBG("cPlaylist: Found %d matching files", n);
+
+    delete parser;
+
     return n;
   }
 
@@ -836,10 +910,10 @@ int cPlaylist::ReadPlaylist(const char *file)
 
 static cString LastDir(cString& path)
 {
-  cString tmp = strdup(path);
-  char *pt = strrchr(tmp, '/');
+  cString tmp = path;
+  const char *pt = strrchr(tmp, '/');
   if(pt && pt > *tmp) {
-    *pt = 0;
+    tmp.Truncate(pt - tmp);
     pt = strrchr(tmp, '/');
     if(pt)
       return cString(pt+1);
@@ -854,9 +928,10 @@ bool cPlaylist::Read(const char *PlaylistFile, bool Recursive)
 
   // extract playlist root folder
   if(!*m_Folder) {
+    const char *pt;
     m_Folder = PlaylistFile;
-    if(strrchr(m_Folder, '/'))
-      *(strrchr(m_Folder, '/') + 1) = 0;
+    if (NULL != (pt=strrchr(m_Folder, '/')))
+      m_Folder.Truncate(pt - m_Folder + 1);
   }
 
   if(xc.IsPlaylistFile(PlaylistFile)) {
@@ -865,15 +940,14 @@ bool cPlaylist::Read(const char *PlaylistFile, bool Recursive)
     m_Origin = ePlaylist;
 
     cString dir = LastDir(m_Folder);
-    char *name = strrchr(PlaylistFile, '/');
+    const char *name = strrchr(PlaylistFile, '/');
     name = name ? name+1 : NULL;
     if(*dir && name)
       m_Name = cString::sprintf("%s - %s", *dir, name);
     else
       m_Name = name ?: "";
 
-    if(strrchr(m_Name, '.'))
-      *(strrchr(m_Name, '.')) = 0;
+    strip_extension(m_Name);
 
   } else if(PlaylistFile[                     0] == '/'  &&
             PlaylistFile[strlen(PlaylistFile)-1] == '/') {
@@ -884,7 +958,7 @@ bool cPlaylist::Read(const char *PlaylistFile, bool Recursive)
 
     if(!*m_Name) {
       m_Name = PlaylistFile;
-      *(strrchr(m_Name, '/')) = 0;
+      m_Name.Truncate( strrchr(m_Name, '/') - m_Name);
       if(strrchr(m_Name, '/')) {
 	cString dir = LastDir(m_Name);
 	if(*dir)
@@ -915,56 +989,35 @@ bool cPlaylist::Read(const char *PlaylistFile, bool Recursive)
   return Result;
 }
 
-cString cPlaylist::EscapeMrl(const char *mrl)
+static cString EscapeString(const char *s)
 {
   static const uint8_t hex[16] = {'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'};
-  const uint8_t *fn = (const uint8_t*)mrl;
-  int size = strlen(mrl) + 16;
-  uint8_t *buf = (uint8_t*)malloc(size);
-  int i = 0, found = 0;
-  LOGDBG("cPlaylist::EscapeMrl('%s')", fn);
-
-  // Wait for first '/' (do not escape mrl start dvd:/, http://a@b/, ...)
-  if (*fn == '/')
-    found = 3;
+  const uint8_t *fn = (const uint8_t*)s;
+  int size = strlen(s) + 16;
+  char *buf = (char *)malloc(size);
+  int i = 0;
+  LOGVERBOSE("EscapeString('%s')", fn);
 
   while (*fn) {
     if(size-7 < i)
-      buf = (uint8_t *)realloc(buf, (size=size+16));
+      buf = (char *)realloc(buf, (size=size+16));
     switch (*fn) {
     case 1 ... ' ':
     case 127 ... 255:
     case '#':
     case '%':
+    case '?':
     case ':':
     case ';':
     case '\'':
     case '\"':
     case '(':
     case ')':
-      if (found > 2) {
-	buf[i++] = '%';
-	buf[i++] = hex[(*fn & 0xf0)>>4];
-	buf[i++] = hex[(*fn & 0x0f)];
-	break;
-      }
+      buf[i++] = '%';
+      buf[i++] = hex[(*fn & 0xf0)>>4];
+      buf[i++] = hex[(*fn & 0x0f)];
+      break;
     default:
-      // file:/... -> only one '/' before escaping
-      // http://.../ --> three '/' before escaping
-      if(!found && (fn[0] == ':' && fn[1] == '/')) {
-	if(fn[2] == '/') {
-	  // ex. http://user:pass@host/... --> wait for third '/'
-	  buf[i++] = *fn++;
-	  buf[i++] = *fn++;
-	  found += 2;
-	} else {
-	  //  ex. file:/local_file
-	  buf[i++] = *fn++;
-	  found += 3;
-	}
-      } else if(*fn == '/') {
-	found++;
-      }
       buf[i++] = *fn;
       break;
     }
@@ -972,13 +1025,22 @@ cString cPlaylist::EscapeMrl(const char *mrl)
   }
 
   buf[i] = 0;
-  LOGDBG("    --> '%s'", buf);
-  return cString((const char*)buf, true);
+  LOGVERBOSE("    --> '%s'", buf);
+  return cString(buf, true);
+}
+
+cString cPlaylist::BuildMrl(const char *proto, const char *s1, const char *s2, const char *s3, const char *s4)
+{
+  return cString::sprintf("%s:%s%s%s%s",
+                          proto,
+                          s1 ? *EscapeString(s1) : "",
+                          s2 ? *EscapeString(s2) : "",
+                          s3 ? *EscapeString(s3) : "",
+                          s4 ? *EscapeString(s4) : "");
 }
 
 cString cPlaylist::GetEntry(cPlaylistItem *i, bool isPlaylist, bool isCurrent)
 {
-
   cString Entry = "";
   if ((*i->Artist && xc.playlist_artist) || (*i->Album && xc.playlist_album)) {
       Entry = cString::sprintf("%s%s%s%s%s%s(%s%s%s)",
