@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: udp_pes_scheduler.c,v 1.56 2011/02/28 13:15:08 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -186,6 +186,7 @@ bool cUdpScheduler::AddRtp(void)
 
   if(xc.remote_local_ip[0]) {
     struct sockaddr_in name;
+    memset(&name, 0, sizeof(name));
     name.sin_family = AF_INET;
     name.sin_addr.s_addr = inet_addr(xc.remote_local_ip);
     if(name.sin_addr.s_addr == INADDR_NONE)
@@ -227,6 +228,7 @@ bool cUdpScheduler::AddRtp(void)
 
   if(xc.remote_local_ip[0]) {
     struct sockaddr_in name;
+    memset(&name, 0, sizeof(name));
     name.sin_family = AF_INET;
     name.sin_addr.s_addr = inet_addr(xc.remote_local_ip);
     name.sin_port = htons(xc.remote_rtp_port+1);
@@ -575,13 +577,14 @@ void cUdpScheduler::Send_RTCP(void)
     msg->hdr.count  = 1;
 
     msg->sdes.ssrc   = m_ssrc;
-    msg->sdes.item[0].type   = RTCP_SDES_CNAME;
-    sprintf(msg->sdes.item[0].data, "VDR@%s:%d%c%c%c", 
+    rtcp_sdes_item_t *it = &msg->sdes.item[0];
+    it->type   = RTCP_SDES_CNAME;
+    sprintf(it->data, "VDR@%s:%d%c%c%c",
 	    hostname[0] ? hostname : xc.remote_rtp_addr,
 	    xc.remote_rtp_port, 0, 0, 0);
-    msg->sdes.item[0].length = strlen(msg->sdes.item[0].data);
-    msg->hdr.length = htons(1 + 1 + ((msg->sdes.item[0].length - 2) + 3) / 4); 
-    
+    it->length = strlen(it->data);
+    msg->hdr.length = htons(1 + 1 + ((it->length - 2) + 3) / 4);
+
     content += sizeof(rtcp_common_t) + 4*ntohs(msg->hdr.length);
     msg = (rtcp_packet_t *)content;
 
@@ -625,8 +628,8 @@ void cUdpScheduler::Send_SAP(bool Announce)
                                               2001,
                                               xc.listen_port,
                                               xc.remote_rtp_addr,
-                                              payload_type,
                                               m_ssrc,
+                                              payload_type,
                                               xc.remote_rtp_port,
                                               xc.remote_rtp_ttl);
   if(!sdp_descr)
@@ -635,7 +638,12 @@ void cUdpScheduler::Send_SAP(bool Announce)
 #if 1
   /* store copy of SDP data */
   if(m_fd_sap < 0) {
-    cString fname = AddDirectory(VideoDirectory,
+    cString fname = AddDirectory(
+#if defined(APIVERSNUM) && (APIVERSNUM < 20102)
+				 VideoDirectory,
+#else
+				 cVideoDirectory::Name(),
+#endif
 				 cString::sprintf("xineliboutput@%s.sdp",
 						  ip));
     FILE *fp = fopen(fname, "w");
@@ -674,7 +682,7 @@ void cUdpScheduler::Schedule(const uchar *Data, int Length)
 
   if (DATA_IS_TS(Data)) {
     if (ts_get_pcr_n(Data, Length/TS_SIZE, &pts)) {
-      LOGSCR("UDP PCR: %"PRId64, pts);
+      LOGSCR("UDP PCR: %" PRId64, pts);
       ScrSource = eScrFromPcr;
       elapsed   = CalcElapsedVtime(pts, eScrFromPcr);
     }
