@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: osd_manager.c,v 1.27 2013/01/17 21:05:16 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -15,9 +15,9 @@
 #include <xine/xine_internal.h>
 #include <xine/video_out.h>
 
-#include "../xine_osd_command.h"
 #include "../xine_input_vdr.h"
 
+#include "../tools/osd_command.h"
 #include "../tools/rle.h"
 
 #include "vo_props.h"
@@ -138,7 +138,7 @@ static void release_ticket(osd_manager_impl_t *this)
 /*
  * get_overlay_manager()
  */
-video_overlay_manager_t *get_ovl_manager(osd_manager_impl_t *this)
+static video_overlay_manager_t *get_ovl_manager(osd_manager_impl_t *this)
 {
   /* Get overlay manager. We need ticket ... */
   acquire_ticket(this);
@@ -156,7 +156,7 @@ video_overlay_manager_t *get_ovl_manager(osd_manager_impl_t *this)
 
 #define saturate(x,min,max) ( (x)<(min) ? (min) : (x)>(max) ? (max) : (x))
 
-static void palette_argb_to_ayuv(xine_clut_t *clut, int colors)
+static void palette_argb_to_ayuv(osd_clut_t *clut, int colors)
 {
   if (clut && colors>0) {
     int c;
@@ -194,7 +194,7 @@ static void clear_osdcmd(osd_command_t *cmd)
  */
 static void osdcmd_to_overlay(vo_overlay_t *ovl, osd_command_t *cmd)
 {
-  uint i;
+  unsigned i;
 
   ovl->rle       = (rle_elem_t*)cmd->data;
   ovl->data_size = cmd->datalen;
@@ -244,10 +244,10 @@ static void osdcmd_scale(osd_manager_impl_t *this, osd_command_t *cmd,
   osd->cmd.datalen = cmd->datalen;
 
   /* scale */
-  int rle_elems = cmd->datalen / sizeof(xine_rle_elem_t);
+  int rle_elems = cmd->datalen / sizeof(osd_rle_elem_t);
   cmd->data = rle_scale_nearest(cmd->data, &rle_elems, cmd->w, cmd->h,
                                 new_w, new_h);
-  cmd->datalen = rle_elems * sizeof(xine_rle_elem_t);
+  cmd->datalen = rle_elems * sizeof(osd_rle_elem_t);
 
   cmd->x = new_x;
   cmd->y = new_y;
@@ -472,7 +472,7 @@ static int exec_osd_set_rle(osd_manager_impl_t *this, osd_command_t *cmd)
       palette_argb_to_ayuv(cmd->palette, cmd->colors);
     cmd->flags |= OSDFLAG_YUV_CLUT;
 
-    osd->cmd.palette = malloc(sizeof(xine_clut_t)*cmd->colors);
+    osd->cmd.palette = malloc(sizeof(osd_clut_t)*cmd->colors);
     memcpy(osd->cmd.palette, cmd->palette, 4*cmd->colors);
     osd->cmd.flags |= OSDFLAG_YUV_CLUT;
   }
@@ -671,7 +671,7 @@ static int exec_osd_set_argb(osd_manager_impl_t *this, osd_command_t *cmd)
 
   /* allocate buffer */
   if (!osd->argb_buffer) {
-    osd->argb_buffer = calloc(sizeof(uint32_t), osd->extent_width * osd->extent_height);
+    osd->argb_buffer = calloc(sizeof(uint32_t), (size_t)osd->extent_width * (size_t)osd->extent_height);
   }
   if (!osd->argb_layer) {
     set_argb_layer(&osd->argb_layer, argb_layer_create());
@@ -723,9 +723,9 @@ static int exec_osd_set_argb(osd_manager_impl_t *this, osd_command_t *cmd)
 #define MIN(a,b) ((a)<(b)?(a):(b))
 #define MAX(a,b) ((a)>(b)?(a):(b))
   osd->argb_layer->x1 = MIN( osd->argb_layer->x1, cmd->x );
-  osd->argb_layer->x2 = MAX( osd->argb_layer->x2, cmd->x + cmd->w );
+  osd->argb_layer->x2 = MAX( osd->argb_layer->x2, cmd->x + cmd->w - 1);
   osd->argb_layer->y1 = MIN( osd->argb_layer->y1, cmd->y );
-  osd->argb_layer->y2 = MAX( osd->argb_layer->y2, cmd->y + cmd->h );
+  osd->argb_layer->y2 = MAX( osd->argb_layer->y2, cmd->y + cmd->h - 1);
 #endif
 
   /* set buffer (ref-counted) */
@@ -777,8 +777,8 @@ static int exec_osd_set_palette(osd_manager_impl_t *this, osd_command_t *cmd)
   /* replace palette */
   tmp.cmd      = OSD_Set_RLE;
   free(tmp.palette);
-  tmp.palette  = malloc(cmd->colors*sizeof(xine_rle_elem_t));
-  memcpy(tmp.palette, cmd->palette, cmd->colors*sizeof(xine_rle_elem_t));
+  tmp.palette  = malloc(cmd->colors * sizeof(osd_rle_elem_t));
+  memcpy(tmp.palette, cmd->palette, cmd->colors * sizeof(osd_rle_elem_t));
   tmp.colors   = cmd->colors;
   tmp.pts      = cmd->pts;
   tmp.delay_ms = cmd->delay_ms;
