@@ -4,12 +4,16 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: xine_frontend.c,v 1.126 2012/03/19 11:51:21 phintuka Exp $
+ * $Id$
  *
  */
 
 #include "features.h"
 
+#ifndef _GNU_SOURCE
+# define _GNU_SOURCE // asprintf
+#endif
+
 #include <inttypes.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -145,12 +149,6 @@ static void make_dirs(const char *file)
 
 static void list_plugins_type(xine_t *xine, const char *msg, typeof (xine_list_audio_output_plugins) list_func)
 {
-  static xine_t *tmp_xine = NULL;
-  if(!xine) {
-    if(!tmp_xine)
-      xine_init(tmp_xine = xine_new());
-    xine = tmp_xine;
-  }
   const char *const *list = list_func(xine);
 
   printf("%s", msg);
@@ -959,11 +957,11 @@ static void fe_post_unload(const fe_t *this)
 
 static void fe_post_close(const fe_t *this, const char *name, int which)
 {
-  post_plugins_t *posts = this->postplugins;
-
   if(!this)
     return;
 
+  post_plugins_t *posts = this->postplugins;
+
   if(name && !strcmp(name, "AudioVisualization")) {
     name = NULL;
     which = POST_AUDIO_VIS;
@@ -1042,13 +1040,13 @@ static int get_opt_val(const char *s, const char *opt)
 
 static void fe_post_open(const fe_t *this, const char *name, const char *args)
 {
+  if(!this || !this->xine || !this->stream || !name)
+    return;
+
   post_plugins_t *posts = this->postplugins;
   char initstr[1024];
   int found = 0;
 
-  if(!this || !this->xine || !this->stream || !name)
-    return;
-
   /* pip */
   if(!strcmp(name, "Pip")) {
     posts->post_pip_enable = 1;
@@ -1225,8 +1223,6 @@ static void fe_xine_close(frontend_t *this_gen)
 
     fe_xine_stop(this_gen);
 
-    fe_post_unload(this);
-
     xine_close(this->stream);
     if(this->postplugins->pip_stream) 
       xine_close(this->postplugins->pip_stream);
