@@ -4,7 +4,7 @@
  * See the main source file 'xineliboutput.c' for copyright information and
  * how to reach the author.
  *
- * $Id: xine_sxfe_frontend.c,v 1.205 2013/08/18 07:58:29 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -37,6 +37,9 @@
 #ifdef HAVE_XINERAMA
 #  include <X11/extensions/Xinerama.h>
 #endif
+#ifdef HAVE_XRANDR
+#  include <X11/extensions/Xrandr.h>
+#endif
 
 #ifdef HAVE_OPENGL
 #  include <GL/glx.h>
@@ -53,13 +56,13 @@
 #define LOG_MODULENAME "[vdr-sxfe]  "
 #include "logdefs.h"
 
-#include "xine_osd_command.h"
 #include "xine_frontend_internal.h"
 
 #ifdef HAVE_DBUS_GLIB_1
 #  include "tools/gnome_screensaver.h"
 #endif
 
+#include "tools/osd_command.h"
 #include "tools/rle.h"
 #include "tools/time_ms.h"
 
@@ -823,7 +826,7 @@ static void update_mask(uint32_t* dst, int dst_pitch,
                         uint32_t* mask, int mask_pitch,
                         int *mask_changed, const struct osd_command_s *cmd)
 {
-  uint x, y;
+  unsigned x, y;
   *mask_changed = 0;
 
   dst  += dst_pitch  * cmd->y + cmd->x;
@@ -1019,6 +1022,15 @@ static int hud_osd_command(frontend_t *this_gen, struct osd_command_s *cmd)
     if (!(cmd->flags & OSDFLAG_TOP_LAYER))
       return 1;
 
+    if (this->osd_height > HUD_MAX_HEIGHT ||
+        this->osd_width  > HUD_MAX_WIDTH) {
+      // XXX TODO crop or scale ?
+      // really dimensions should be runtime param, not constant...
+      LOGMSG("HUD ERROR: Unsupported OSD size: %dx%d is larger than %dx%d",
+             this->osd_width, this->osd_height, HUD_MAX_WIDTH, HUD_MAX_HEIGHT);
+      return 1;
+    }
+
     XLockDisplay(this->display);
     switch (cmd->cmd) {
     case OSD_Nop: /* Do nothing ; used to initialize delay_ms counter */
@@ -1417,7 +1429,7 @@ static void set_icon(sxfe_t *this)
 #else
   long      q[2+32*32];
   uint32_t *p = (uint32_t*)&vdrlogo_32x32;
-  uint      i;
+  unsigned  i;
   for (i = 0; i < 2 + vdrlogo_32x32.width*vdrlogo_32x32.height; i++)
     q[i] = p[i];
   XChangeProperty(this->display, this->window[0],
@@ -2564,6 +2576,90 @@ static void sxfe_toggle_fullscreen(fe_t *this_gen, int fullscreen)
   this->fullscreen_state_forced = !force;
 }
 
+static unsigned char *sxfe_display_edid(frontend_t *this_gen, int *size)
+{
+  sxfe_t *this = (sxfe_t*)this_gen;
+  unsigned char *edid = NULL;
+
+#ifdef HAVE_XRANDR
+
+  XLockDisplay(this->display);
+
+  do {
+    if (!this->display)
+      break;
+
+    int event_base, error_base;
+    int major, minor;
+    if (!XRRQueryExtension(this->display, &event_base, &error_base) ||
+        !XRRQueryVersion(this->display, &major, &minor)) {
+      LOGMSG("edid: RandR extension missing");
+      break;
+    }
+    if (major < 1 || (major == 1 && minor < 2)) {
+      LOGMSG("edid: RandR extension < 1.2");
+      break;
+    }
+
+    XRRScreenResources *res;
+    res = XRRGetScreenResourcesCurrent(this->display, this->root_window);
+    if (!res) {
+      LOGMSG("edid: failed getting screen resources");
+      break;
+    }
+
+    int o;
+    for (o = 0; o < res->noutput && !edid; o++) {
+      XRROutputInfo *output_info = XRRGetOutputInfo(this->display, res, res->outputs[o]);
+      if (!output_info) {
+        LOGMSG("edid: failed getting output %d information", o);
+        continue;
+      }
+      if (output_info->connection != RR_Connected) {
+        LOGDBG("edid: output %s not connected", output_info->name);
+        continue;
+      }
+      LOGDBG("edid: checking connected output %s", output_info->name);
+
+      int nprop, j;
+      Atom *props = XRRListOutputProperties(this->display, res->outputs[o], &nprop);
+      for (j = 0; j < nprop && !edid; j++) {
+        char *atom_name = XGetAtomName(this->display, props[j]);
+
+        if (!strcmp(atom_name, "EDID")) {
+
+          unsigned char *prop;
+          int actual_format;
+          unsigned long nitems, bytes_after;
+          Atom actual_type;
+          XRRGetOutputProperty(this->display, res->outputs[o], props[j],
+                               0, 100, False, False,
+                               AnyPropertyType,
+                               &actual_type, &actual_format,
+                               &nitems, &bytes_after, &prop);
+          if (actual_format == 8 && actual_type == XA_INTEGER) {
+            LOGDBG("edid: Found EDID, %ld bytes", nitems);
+            *size = nitems;
+            edid = malloc(*size);
+            memcpy(edid, prop, *size);
+            break;
+          }
+        }
+      }
+    }
+  } while (0);
+
+  XUnlockDisplay(this->display);
+
+  if (!edid) {
+    LOGMSG("no EDID found");
+  }
+#endif /* HAVE_XRANDR */
+
+  return edid;
+}
+
+
 /*
  *   X event loop
  */
@@ -2699,14 +2795,31 @@ static void XConfigureEvent_handler(sxfe_t *this, XConfigureEvent *cev)
 
   /* update video window size */
   if (this->x.width != cev->width || this->x.height != cev->height) {
-    LOGDBG("Video window size changed from %dx%d to %dx%d", this->x.width, this->x.height, cev->width, cev->height);
-    this->x.width  = cev->width;
-    this->x.height = cev->height;
 
-    /* inform VDR about new size */
-    char str[128];
-    snprintf(str, sizeof(str), "INFO WINDOW %dx%d", this->x.width, this->x.height);
-    this->x.fe.send_event((frontend_t*)this, str);
+    if ( ( this->fullscreen && this->window[1] == cev->window) ||
+         (!this->fullscreen && this->window[0] == cev->window)) {
+
+      LOGDBG("Video window size changed from %dx%d to %dx%d", this->x.width, this->x.height, cev->width, cev->height);
+
+      this->x.width  = cev->width;
+      this->x.height = cev->height;
+
+      /* inform VDR about new size */
+      char str[128];
+      int w = this->x.width;
+      int h = this->x.height;
+#ifdef HAVE_XRENDER
+      // XXX quick fix for UHD displays. Should be fixed in overlay handling, not here.
+      if (this->hud) {
+        if (w > HUD_MAX_WIDTH)
+          w = HUD_MAX_WIDTH;
+        if (h > HUD_MAX_HEIGHT)
+          h = HUD_MAX_HEIGHT;
+      }
+#endif
+      snprintf(str, sizeof(str), "INFO WINDOW %dx%d", w, h);
+      this->x.fe.send_event((frontend_t*)this, str);
+    }
   }
 
   if(this->window[0] == cev->window && this->check_move) {
@@ -3099,6 +3212,7 @@ static frontend_t *sxfe_get_frontend(void)
 
   this->fe.fe_display_open   = sxfe_display_open;
   this->fe.fe_display_config = sxfe_display_config;
+  this->fe.fe_display_edid   = sxfe_display_edid;
   this->fe.fe_display_close  = sxfe_display_close;
 
   this->fe.fe_run       = sxfe_run;
