@@ -1,7 +1,7 @@
 /*
  * vdr-xineliboutput: xine-lib based output device plugin for VDR
  *
- * Copyright (C) 2003-2008 Petri Hintukainen <phintuka@users.sourceforge.net>
+ * Copyright (C) 2003-2017 Petri Hintukainen <phintuka@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@
  *
  * xineliboutput.c: VDR Plugin interface
  *
- * $Id: xineliboutput.c,v 1.58 2013/08/20 09:09:33 phintuka Exp $
+ * $Id$
  *
  */
 
@@ -37,21 +37,22 @@
 #include "menu.h"
 #include "media_player.h"
 
-#if defined(APIVERSNUM) && (APIVERSNUM < 10600)
-# error VDR API versions < 1.6.0 are not supported !
+#if defined(APIVERSNUM) && (APIVERSNUM < 10733)
+# error VDR API versions < 1.7.33 are not supported !
 #endif
 
 //---------------------------------plugin-------------------------------------
 
-static const char *VERSION        = "1.1.0";
+static const char *VERSION        = "2.0.0";
 static const char *DESCRIPTION    = trNOOP("X11/xine-lib output plugin");
 static const char *MAINMENUENTRY  = trNOOP("Media Player");
 
-class cPluginXinelibOutput : public cPlugin 
+class cPluginXinelibOutput : public cPlugin
 {
   private:
     // Add any member variables or functions you may need here.
     cXinelibDevice *m_Dev;
+    int             m_MakePrimary;
 
   public:
     cPluginXinelibOutput(void);
@@ -88,6 +89,7 @@ cPluginXinelibOutput::cPluginXinelibOutput(void)
   // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
 
   m_Dev = NULL;
+  m_MakePrimary = 0;
 }
 
 cPluginXinelibOutput::~cPluginXinelibOutput()
@@ -107,7 +109,7 @@ const char cmdLineHelp[] =
 "                           fbfe    (framebuffer)\n"
 "                           none    (only remote frontends)\n"
 "  -r PORT   --remote=PORT  Listen PORT for remote clients\n"
-"                           (default "LISTEN_PORT_S")\n"
+"                           (default " LISTEN_PORT_S ")\n"
 "                           none or 0 disables remote mode\n"
 "                           Also local interface address can be specified:\n"
 "                           --remote=<ip>:<port>  (default is all interfaces)\n"
@@ -158,6 +160,8 @@ const char cmdLineHelp[] =
 "                           there are active frontend(s)\n"
 "  -c        --exit-on-close  Exit vdr when local frontend window is closed\n"
 "  -C        --config=file  Use xine-lib config file\n"
+"  -t        --truecolor    Support True Color OSD if no client is connected\n"
+"  -s        --auto-suspend Trigger vdr-suspendoutput when there are no clients\n"
 ;
 
 const char *cPluginXinelibOutput::CommandLineHelp(void)
@@ -194,6 +198,12 @@ void cPluginXinelibOutput::MainThreadHook(void)
 {
   TRACEF("cPluginXinelibOutput::MainThreadHook");
 
+  if (m_MakePrimary) {
+     LOGDBG("Switching primary device to %d", m_MakePrimary);
+     cDevice::SetPrimaryDevice(m_MakePrimary);
+     m_MakePrimary = 0;
+     }
+
   if (m_Dev) {
     m_Dev->MainThreadHook();
   }
@@ -328,6 +338,9 @@ const char **cPluginXinelibOutput::SVDRPHelpPages(void)
     "    Queue music file to playlist.",
     "LFRO <frontend>\n"
     "    Start/stop local frontend. <frontend> can be none, sxfe or fbfe.",
+    "PRIM <n>\n"
+    "    Make <n> the primary device. If <n> is missing,\n"
+    "    xineliboutput will become the primary device.",
     NULL
     };
   return HelpPages;
@@ -400,6 +413,20 @@ cString cPluginXinelibOutput::SVDRPCommand(const char *Command, const char *Opti
     }
   }
 
+  else if(strcasecmp(Command, "PRIM") == 0) {
+    int primary = 0;
+    if(*Option) {
+      LOGMSG("SVDRP(%s, %s)", Command, Option);
+      primary = strtol(Option, NULL, 0);
+    } else {
+      LOGMSG("SVDRP(%s)", Command);
+    }
+    if(!primary && m_Dev)
+        primary = m_Dev->DeviceNumber() + 1;
+    m_MakePrimary = primary;
+    return cString::sprintf("Switching primary device to %d", primary);
+  }
+
   return NULL;
 }
 
